﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Net;
using System.Windows;
using Microsoft.Phone.Controls;

namespace Mp3StoreandPlayback
{
    public partial class MainPage : PhoneApplicationPage
    {
        Media.Mp3MediaStreamSource mss;
        IsolatedStorageFileStream audio;

        // Constructor
        public MainPage()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            // iterate via isolated storage to get the 
            // list of items stored
            RefreshIsoFiles();
        }

        private void RefreshIsoFiles()
        {
            string[] fileList;

            using (var store = IsolatedStorageFile.GetUserStoreForApplication())
            {
                fileList = store.GetFileNames();
            }
            listBox1.ItemsSource = fileList;
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            string fileName = System.IO.Path.GetFileName(mpsUri.Text);

            if (string.IsNullOrEmpty(mpsUri.Text))
            {
                MessageBox.Show("No URI specified");
            }

            if (!mpsUri.Text.EndsWith(".mp3"))
            {
                MessageBox.Show("Doesn't look like an MP3 file?");
            }

            // start the download of the MP3
            WebClient wc = new WebClient();

            wc.OpenReadCompleted += ((s, args) =>
                {
                    DownloadProgress.IsIndeterminate = false;

                    // once get the streams, put in isolated storage
                    using (var store = IsolatedStorageFile.GetUserStoreForApplication())
                    {
                        if (store.FileExists(fileName))
                        {
                            store.DeleteFile(fileName);
                        }

                        using (var fs = new IsolatedStorageFileStream(fileName, FileMode.Create, store))
                        {
                            byte[] bytesInStream = new byte[args.Result.Length];
                            args.Result.Read(bytesInStream, 0, (int)bytesInStream.Length);
                            fs.Write(bytesInStream, 0, bytesInStream.Length);
                            fs.Flush();
                        }
                    }

                    RefreshIsoFiles();

                });

            wc.OpenReadAsync(new System.Uri(mpsUri.Text, System.UriKind.RelativeOrAbsolute));
            DownloadProgress.IsIndeterminate = true;
        }

        private void button2_Click(object sender, RoutedEventArgs e)
        {
            if (listBox1.SelectedItem == null)
            {
                MessageBox.Show("choose an item to play back!");
            }
            else
            {
                using (var store = IsolatedStorageFile.GetUserStoreForApplication())
                {
                    audio = store.OpenFile(listBox1.SelectedItem.ToString(), FileMode.Open);
                    // play it back as a MSS
                    mss = new Media.Mp3MediaStreamSource(audio);
                    mediaPlayback.SetSource(mss);
                }
            }
        }

        private void button3_Click(object sender, RoutedEventArgs e)
        {
            mediaPlayback.Stop();
            mediaPlayback.Source = null;
            mss = null;
            audio.Close();
        }
    }
}